prism.mixture module — prism documentation

# prism.mixture module

class `prism.mixture.` `BetaBinomialMixture`(n_components=1, max_iter=10000, tol=0.001, seed=None, verbose=False)

  Bases: `object`

  Beta-binomial mixture model for PRISM core algorithm.

  `bic`()

    Returns: | Bayesian Information Criterion (BIC) value of the model.

  `dispersions_`
  `fit`(n, k, headers)
  `get_counts`()

    Returns: | Fingerprint pattern counts of fingerprint epiloci used for fitting the model.

  `get_depths`()

    Returns: | Depths of fingerprint epiloci used for fitting the model.

  `get_dispersions`()

    Returns: | Cluster dispersions.

  `get_headers`()

    Returns: | Headers of fingerprint epiloci used for fitting the model.

  `get_means`()

    Returns: | Cluster means.

  `get_n_components`()

    Returns: | Number of clusters.

  `get_n_dimensions`()

    Returns: | Number of dimensions.

  `get_weights`()

    Returns the list of cluster weights. Note that a cluster weight is computed as a sum of posterior probabilities that each of the data point will be assiged to that cluster.

    Returns: | Cluster weights.

  `means_`
  `predict_proba`(n, k)

    Returns the posterior probabilities of each fingerprint epiloci for each cluster.

    Parameters: | n (list) – Depths of fingerprint epiloci. k (list) – Fingerprint pattern counts of fingerprint epiloci.
    Returns: | Posterior probabilities of each fingerprint epiloci.

`prism.mixture.` `trigamma`(x)